# Revision History

## 0.2.1 (2016/10/18)

- Now stripping whitespace after calling `--version` on a program.

## 0.2 (2016/10/17)

- Added `--version` command.

## 0.1 (2016/10/17)

 - Initial release.
